from django.apps import AppConfig
from django.contrib.auth.signals import user_logged_in

from .config import access_and_compliance_group_name


class AccessAndComplianceConfig(AppConfig):
    name = 'django_access_and_compliance'
    verbose = 'Access and Compliance'

    def ready(self):
        from .signals import ensure_compliant
        user_logged_in.connect(ensure_compliant)



import requests
import logging

from django.conf import settings
from django.contrib.auth.models import Group

from .config import access_and_compliance_group_name

logger = logging.getLogger(__name__)


def ensure_compliant(sender, request, user, **kwargs):
    payload = {'uniqname': 'jonathoy'}
    response = requests.get(settings.ACCESS_AND_COMPLIANCE_VALIDATION_URL, params=payload)
    response.raise_for_status()
    group, created = Group.objects.get_or_create(name=access_and_compliance_group_name)
    logger.info('Created access and compliance group')

    if _is_compliant(response):
        group.user_set.add(user)
        logger.debug(f'{user} has attested to the data access and compliance policy')
    else:
        group.user_set.remove(user)
        logger.debug(f'{user} has not attested to data compliance policy')


def _is_compliant(response):
    return response.text in settings.ACCESS_AND_COMPLIANCE_TRUTHY_VALUES



import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-access-and-compliance',
    version='0.1.3',
    packages=find_packages(),
    include_package_data=True,
    description='A Django application for verifying acceptance of the University of \
        Michigan\'s Data Access and Compliance Policy',
    long_description=README,
    long_description_content_type='text/markdown',
    # url='https://www.example.com/',
    author='Jonathon Yu',
    install_requires=[
        'requests>=2.21.0<3',
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP',
    ],
)
